@@ -1,4 +1,4 @@
-# Copyright 2019-2020 Portmod Authors
+# Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
 import os
@@ -8,12 +8,23 @@ from pathlib import Path
 from shutil import which
 from typing import AbstractSet, Iterable, List, Set, Tuple, Union
 
+from portmodlib.fs import is_parent
+from portmodlib.l10n import l10n
+
 from .config import get_config
 from .globals import env
 from .perms import Permissions
 from .win32 import get_personal
 
 
+def _required_exe(name: str) -> str:
+    path = which(name)
+
+    if not path:
+        raise FileNotFoundError(l10n("missing-executable", file=name))
+    return path
+
+
 def resolve_paths(path: str) -> List[str]:
     """
     Returns all paths related to the symlink chain at paths
@@ -52,9 +63,7 @@ def _dedup_subpaths(paths: Iterable[str]) -> List[str]:
     for path in sorted(paths):
         abspath = os.path.abspath(path)
         if os.path.exists(abspath):
-            if any(
-                os.path.commonpath([abspath, usedpath]) == usedpath for usedpath in used
-            ):
+            if any(is_parent(abspath, usedpath) for usedpath in used):
                 continue
             used.append(abspath)
 
@@ -175,7 +184,7 @@ def sandbox_execute(
         )
 
         sandbox_command = (
-            ["bwrap"]
+            [_required_exe("bwrap")]
             + ro_bind
             + bind
             + symlink
@@ -199,8 +208,8 @@ def sandbox_execute(
             sandbox_command.extend(["--bind", env.PYBUILD_TMP_DIR, env.PYBUILD_TMP_DIR])
 
     elif sys.platform == "win32":
-        SINI = f'"{which("sbieini.exe")}"'
-        start_exe = which("start.exe")
+        SINI = _required_exe("sbieini.exe")
+        start_exe = _required_exe("start.exe")
 
         BOXNAME = "Portmod"
         delete_commands = []
@@ -223,8 +232,8 @@ def sandbox_execute(
 
         def add_command(command: str, typ: str, value: str):
             nonlocal delete_commands
-            subprocess.check_call(f'{SINI} {command} {BOXNAME} {typ} "{value}"')
-            delete_commands.append(f'{SINI} delete {BOXNAME} {typ} "{value}"')
+            subprocess.check_call(f'"{SINI}" {command} {BOXNAME} {typ} "{value}"')
+            delete_commands.append(f'"{SINI}" delete {BOXNAME} {typ} "{value}"')
 
         if not permissions.network:
             add_command("append", "ClosedFilePath", "InternetAccessDevices")
@@ -252,7 +261,7 @@ def sandbox_execute(
 
         sandbox_command = []
     elif sys.platform == "darwin":
-        sandbox_command = ["sandbox-exec", "-p"]
+        sandbox_command = [_required_exe("sandbox-exec"), "-p"]
 
         sandbox_profile = """
             (version 1)
