@@ -1,4 +1,4 @@
-# Copyright 2019-2020 Portmod Authors
+# Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
 import json
@@ -28,6 +28,7 @@ from portmodlib.fs import (
     _patch_file,
     ci_exists,
     get_tree_size,
+    is_parent,
     onerror,
 )
 from portmodlib.l10n import l10n
@@ -231,6 +232,8 @@ def install_pkg(mod: Pybuild, use_flags: Set[str]):
         return False
 
     BUILD_DIR = os.path.join(env.TMP_DIR, mod.CATEGORY, mod.P)
+    if os.path.exists(BUILD_DIR):
+        shutil.rmtree(BUILD_DIR, onerror=onerror)
     state = PhaseState(BUILD_DIR)
     assert state.T
     state.A = [source.as_source() for source in sources]
@@ -305,10 +308,7 @@ def install_pkg(mod: Pybuild, use_flags: Set[str]):
         final_install,
         case_sensitive=case_sensitive,
     ):
-        if (
-            os.path.commonpath([dst, env.prefix().VARIABLE_DATA])
-            == env.prefix().VARIABLE_DATA
-        ):
+        if is_parent(dst, env.prefix().VARIABLE_DATA):
             raise PermissionError(
                 l10n("local-dir-reserved", dir=env.prefix().VARIABLE_DATA)
             )
