@@ -1,4 +1,4 @@
-# Copyright 2019-2020 Portmod Authors
+# Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
 # pylint: disable=no-member
@@ -12,7 +12,7 @@ from typing import Callable, Iterable, List, Optional, Pattern, Set, Tuple, cast
 
 from portmodlib.atom import Atom
 from portmodlib.colour import blue, magenta
-from portmodlib.fs import patch_dir
+from portmodlib.fs import is_parent, patch_dir
 from portmodlib.globals import messages_dir, warnings_dir
 from portmodlib.l10n import l10n
 from portmodlib.pybuild import FullPybuild, InstallDir, get_installed_env
@@ -460,18 +460,15 @@ class Pybuild1(FullPybuild):
                 path = os.path.join(self.FILESDIR, patch)
                 apply_patch(path)
 
-    def _install_directory(
-        self, source: str, install_dir: InstallDir, to_install: Set[str]
-    ):
-        case_insensitive = os.environ.get("CASE_INSENSITIVE_FILES", False)
+    def _get_install_dir_dest_specific(self, install_dir: InstallDir) -> str:
         install_dir_dest = self._get_install_dir_dest()
 
         if install_dir.RENAME is None:
-            dest = os.path.normpath(
+            return os.path.normpath(
                 os.path.join(self.D, install_dir_dest, install_dir.PATCHDIR)
             )
         else:
-            dest = os.path.normpath(
+            return os.path.normpath(
                 os.path.join(
                     self.D,
                     install_dir_dest,
@@ -480,6 +477,13 @@ class Pybuild1(FullPybuild):
                 )
             )
 
+    def _install_directory(
+        self, source: str, install_dir: InstallDir, to_install: Set[str]
+    ):
+        case_insensitive = os.environ.get("CASE_INSENSITIVE_FILES", False)
+
+        dest = self._get_install_dir_dest_specific(install_dir)
+
         os.makedirs(dest, exist_ok=True)
         blacklist_entries = install_dir.BLACKLIST or []
 
@@ -541,17 +545,18 @@ class Pybuild1(FullPybuild):
         # Determine if any other InstallDirs are inside this one and add them to the blacklist
         to_ignore = []
         for other_path in to_install:
-            if other_path != source and os.path.commonpath(
-                [source]
-            ) == os.path.commonpath(
-                [os.path.abspath(source), os.path.abspath(other_path)]
+            if other_path != source and is_parent(
+                os.path.abspath(other_path), os.path.abspath(source)
             ):
                 to_ignore.append(other_path)
 
         if os.path.islink(source):
             linkto = os.readlink(source)
             if os.path.exists(dest):
-                os.rmdir(dest)
+                if os.path.islink(dest):
+                    os.remove(dest)
+                else:
+                    os.rmdir(dest)
             os.symlink(linkto, dest, True)
         elif whitelist is not None:
             ignore = get_listfn(whitelist, False)
@@ -590,12 +595,13 @@ class Pybuild1(FullPybuild):
             source_dir_path = os.path.join(
                 install_dir.S or cast(str, self.S), install_dir.PATH
             )
+
             if enabled:
                 info(
                     l10n(
                         "installing-directory-into",
                         dir=magenta(source_dir_path),
-                        dest=magenta(install_dir.PATCHDIR),
+                        dest=magenta(self._get_install_dir_dest_specific(install_dir)),
                     )
                 )
                 for doc_path in set(install_dir.DOC) | {
